#!/bin/bash

# Properties
program_name="Tas Dev"

OPT_DIR="/opt/tctools"

. ${SCRIPT_DIR}/common_jboss.sh
. ${SCRIPT_DIR}/common_tas.sh

cmdArray=("installJava" "installJboss" "installMysql" "installAnt" "installGradle" "installGit" "setupGit" "setupTasSky" "setupTas" "setupSky" "initTas" "initSky" "setupProfile" "setupSSH" "Quit")

function oneKeyInstall() {
	preInstall
	setupSSH
	setupApp

	installJava
	installJboss
	installMysql
	installOther
	setupTas
	setupSky
	setupProfile
	checkoutSys

	initDB
	initTas
	initSky
	cd $CUR_DIR
}

function fullInstallWithDocker() {
	exit
	preInstall
	selectDockerfile
	setupSSH
	setupApp

	installJava
	installJboss
	installOther
	setupTas
	setupSky
	setupProfile
	checkoutSys

	imageOnly
	cd $CUR_DIR
}

function customInstall() {
	askUsername
	echo_line "Please press [Y] to update brew or apt-get, press [S] to skip."
	while read -p "-> " -r -n 1 -s answer; do
		if [[ $answer = [Yy] ]]; then
			setupApp
			break
		elif [[ $answer = [Ss] ]]; then
			break
		fi
	done
	

	echo
	echo_line "Please select you want to execute."
	PS3='# '
	select cmdSel in "${cmdArray[@]}";
	do
		if [ "${cmdSel}" = "Quit" ]; then
			break
		else
			eval $cmdSel
			break
		fi
	done
}

function preInstall() {
	askUsername
	selectJboss
	selectTas
	selectSky
	selectJava

	addKnownHosts "gerrit.truetel.com"

	confirmInstall
}

function confirmInstall() {
	echo_color "======================================================================="
	echo_color "Ldap account:		${user_name}"
	echo_color "Java version:		JDK 1.8.0_45"
	echo_color "Gradle version:		${gradle_ver}"
	echo_color "Ant version:		${ant_ver}"
	echo_color "Git version:		${git_ver}"
	echo_color "Mysql version:		2.6"
	echo_color "Jboss version:		${jbossFileName}"
	echo_color "Jboss loction:		${jboss_home}"
	echo_color "TAS version:		${tas_ver}"
	echo_color "TAS loction:		${tas_dir} -> ~/tashome"
	echo_color "SKYP version:		${skyp_ver}"
	echo_color "SKYP loction:		${skyp_loc}"
	echo_color "Database name:		${tas_db}"
	if [ "$install_mode" = "${options[1]}" ]; then
		echo_color "Dockfiles:		"
	fi
	echo_color "======================================================================="

	echo_line "Please confirm install information, and press [Y] to install."
	while read -p "-> " -r -n 1 -s answer; do
	  if [[ $answer = [Yy] ]]; then
	    break
	  fi
	done
}

function setupSSH() {
	echo_color "-----------"
	echo_color " Setup SSH "
	echo_color "-----------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	if [ ! -f ~/.ssh/id_rsa ] && [ ! -f ~/.ssh/id_dsa ]; then
		echo_line "creating ssh key pair ..."
		execCmd "ssh-keygen -t rsa -b 4096 -P '' -f ~/.ssh/id_rsa"
		echo_line "create ssh key pair done"
	fi

	echo_color "***************"
	echo_color "Please go to gerrit.truetel.com"
	echo_color "and register the following key below"
	echo_color "Please refer to Gerrit Migration Guide"
	echo_color "in tteng.truetel.com for instructions"
	echo_color "***************"

	if [ -f ~/.ssh/id_rsa.pub ]; then
		execCmd "cat ~/.ssh/id_rsa.pub"
	elif [ -f ~/.ssh/id_dsa.pub ]; then
		execCmd "cat ~/.ssh/id_dsa.pub"
	fi
	echo;echo

	echo_line "Please press [Y] after you ssh key has been registered."
	while read -p "-> " -r -n 1 -s answer; do
	  if [[ $answer = [Yy] ]]; then
	    break
	  fi
	done
}

function installOther() {
	echo_color "-------"
	echo_color " Other "
	echo_color "-------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	installGit
	setupGit
	installGradle
	installAnt
}

function setupGit() {
	echo_line "config git... "
	execCmd "git config --global user.name '$user_name'"
	execCmd "git config --global user.email '$user_name@truetel.com'"
}