#!/bin/bash

export REPO_HOME=~/dev/sky
export TAS_HOME=~/tashome
export SKY_HOME=${TAS_HOME}

tas_folder_name="tashome"
tas_loc="$HOME/tasdev"
tas_dir="${tas_loc}/${tas_folder_name}"
tas_db="tctas"
tas_versions=(
	'tasprod-TAS-INT-R7V7-jboss-20180604-1300.tar.gz=http://tips.truetel.com/tasshare/tpastore/TAS/INT/R7V7/tasprod-TAS-INT-R7V7-jboss-20180604-1300.tar.gz'
)
tas_ver=""
tas_url=""

sky_dir=${REPO_HOME}
skyp_loc=${TAS_HOME}
skyp_versions=(
	'skyprod-SKYP-5.1.1-OFF-20180521-1155.tar.gz=http://tips.truetel.com/tasshare/tpastore/SKY/OFF/5.1/skyprod-SKYP-5.1.1-OFF-20180521-1155.tar.gz'
)
skyp_ver=""
skyp_url=""

function askTasInfo() {
	if [ ! "${install_mode}" = "${options[0]}" ]; then
		askTasLocal
		askTasFolderName
		askTasDB
	fi
}

function askTasFolderName() {
	echo_line "Please enter your tashome folder name. Press [ENTER] to use '${tas_folder_name}'."
	read -p "-> " tmp
	if [ ! "${tmp}" = "" ]; then
	    tas_folder_name="${tmp}"
	fi
	echo_color "Your tashome name: ${tas_folder_name}"
}

function askTasLocal() {
	echo_line "Please enter your tashome location. Press [ENTER] to put to '${tas_loc}'."
	read -p "-> " tmp
	if [ ! "${tmp}" = "" ]; then
	    tas_loc="${tmp}"
	fi
	echo_color "Your tashome location: ${tas_loc}/${tas_folder_name}"
}

function askTasDB() {
	echo_line "Please enter your database name. Press [ENTER] to use '${tas_db}'."
	read -p "-> " tmp
	cd
	if [ ! "${tmp}" = "" ]; then
	    tas_db="${tmp}"
	fi
	echo_color "Your database name: ${tas_db}"
}

function selectTas() {
	if [ "${tas_ver}" = "" ] || [ "${tas_url}" = "" ]; then
		if [ "${isFullInstall}" = true ]; then
			tas_ver="${tas_versions[0]%%=*}"
			tas_url="${tas_versions[0]##*=}"
		else
			echo_line "Please select TAS version."
			arrayTmp=(${tas_versions[@]})
			selectOption
			tas_ver="${selKey}"
			tas_url="${selVal}"

			resetSelectOption
		fi
	fi
}

function setupTas() {
	echo_color "-----------"
	echo_color " Setup Tas "
	echo_color "-----------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	cd $CUR_DIR
	selectTas
	askTasInfo

	if [ ! -f ${TMP_DIR}/${tas_ver} ]; then
		echo_line "Download ${tas_ver} TAS..."
		execCmd "wget -P $TMP_DIR ${tas_url}"
	else
		echo_line "${tas_ver} already exists..."
	fi

	if [ ! -d $tas_dir ]; then
		execCmd "mkdir -p $tas_dir"
	else
		if [ -d $tas_dir/prod ]; then
			echo_line "Remove tashome prod."
			execCmd "rm -rf $tas_dir/prod/"
		fi
	fi

	echo_line "Unzip TAS to $tas_dir"
	execCmd "tar zxvf ${TMP_DIR}/${tas_ver} -C $tas_dir"

	# setup dynamic link to tashome
	if [ ! -d ${TAS_HOME} ]; then
		echo_line "Create link ${TAS_HOME} to ${tas_dir}"
		execCmd "ln -s $tas_dir ${TAS_HOME}"
	fi

	setupTasrtenv
}

function setupTasrtenv() {
	echo_line "Setup tasrtenv.sh"

	mkDir "${tas_dir}"

	if [ ! -f $tas_dir/tasrtenv.sh ]; then
		echo_line "Copy tasrtenv.sh from ${CONF_DIR}/tasrtenv.sh to $tas_dir/tasrtenv.sh"
		execCmd "cp ${CONF_DIR}/tasrtenv.sh $tas_dir/tasrtenv.sh"
		execCmd "sed -i'' -e \"s/export TAS_DB_URL=127.0.0.1:3306\/tctas/export TAS_DB_URL=127.0.0.1:3306\/${tas_db}/g\" $tas_dir/tasrtenv.sh"

		#if [ "$install_mode" = "${options[1]}" ]; then
		#	if [ ! "$docker_sel_dir" = "" ]; then
		#		echo_line "Copy tasrtenv.sh from $docker_sel_dir/tasrtenv.sh to $tas_dir/tasrtenv.sh"
		#		execCmd "cp $docker_sel_dir/tasrtenv.sh $tas_dir/tasrtenv.sh"
		#	fi
		#fi
	fi
}

function initDB() {
	echo_color "---------------------"
	echo_color " Executing initBD... "
	echo_color "---------------------"

	mysql -u root -e "GRANT all ON *.* TO 'tasadm'@'%' identified by 'tasadm';"
	mysql -u root -e "GRANT all ON *.* TO 'tasadm'@'localhost' identified by 'tasadm';"
	mysql -u root -e "CREATE DATABASE ${tas_db} DEFAULT CHARACTER SET utf8 DEFAULT COLLATE utf8_bin;"
}

function initTas() {
	echo_color "----------"
	echo_color " Init TAS "
	echo_color "----------"

	execCmd ". $tas_dir/tasrtenv.sh"
	execCmd "source $tas_dir/tasrtenv.sh"
	execCmd "taspatch.sh"
	execCmd "tasdbinit.sh"
}

function initSky() {
	echo_color "-----------------------"
	echo_color " Executing init SKY... "
	echo_color "-----------------------"

	execCmd "cd ${skyp_loc}/skyprod/unix/script/"
	execCmd "./skypatch.sh"
	execCmd "./skydbinit.sh"
}

function selectSky() {
	if [[ "${skyp_ver}" = "" || "${skyp_url}" = "" ]]; then
		if [ "${isFullInstall}" = true ]; then
			skyp_ver="${skyp_versions[0]%%=*}"
			skyp_url="${skyp_versions[0]##*=}"
		else
			echo_line "Please select SKY version."
			arrayTmp=(${skyp_versions[@]})
			selectOption
			skyp_ver="${selKey}"
			skyp_url="${selVal}"

			resetSelectOption
		fi
	fi
}

function setupSky() {
	echo_color "-----------"
	echo_color " Setup SKY "
	echo_color "-----------"

	if [ ! -d ${TAS_HOME} ]; then
		exitProc "Please install TAS first."
	fi

	selectSky

	if [ ! -f ${TMP_DIR}/${skyp_ver} ]; then
		echo_line "Download ${skyp_ver}..."
		execCmd "wget -P $TMP_DIR ${skyp_url}"
	else
		echo_line "${skyp_ver} already exists..."
	fi

	if [ ! -d $skyp_loc ]; then
		execCmd "mkdir -p $skyp_loc"
	else
		if [ -d $skyp_loc/skyp_ver ]; then
			echo_line "Remove ${skyp_ver}."
			execCmd "rm -rf $skyp_loc/skyp_ver"
		fi
	fi

	echo_line "Unzip SKY to $skyp_loc"
	execCmd "tar zxvf ${TMP_DIR}/${skyp_ver} -C $skyp_loc"
	checkoutSys
}

function checkoutSkyRepo() {
	tmpDir=`pwd`
	execCmd "cd ${sky_dir}"

	if ! commandExists "git"; then
		installGit
	fi

	if [ ! -d $sky_dir/$1 ]; then
		execCmd "git clone ssh://$user_name@gerrit.truetel.com:29418/$1"
	else
		execCmd "cd $1"
		execCmd "git reset --hard"
		execCmd "git pull origin master"
	fi

	execCmd "cd ${tmpDir}"
}

function checkoutSys() {
	# must after setupProfile
	echo_color "------------------"
	echo_color " Checkout systems "
	echo_color "------------------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	echo_line "Checking out sky source code... "
	mkDir "${sky_dir}"
	execCmd "cd ${sky_dir}"

	checkoutSkyRepo "systems"

	#execCmd "gradle forall -Pcmd=\"ant setup.eclipse.prj\""
	execCmd "cd $CUR_DIR"
	echo_line "Check out systems done"
}

function setupProfile() {
	echo_color "---------"
	echo_color " Profile "
	echo_color "---------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	echo_line "Setting up profiles..."
	#execCmd "cd $CUR_DIR"

	if [ -f ~/.bashrc ]; then
		profName="~/.bashrc"
	else
		profName="~/.bash_profile"
	fi

	execCmd "cp ${CONF_DIR}/host_tt_profile ~/.tt_profile"
	execCmd "touch ${profName}"
	execCmd "sed -i -e '/. ~\/.tt_profile/d' ${profName}"
	execCmd "echo '. ~/.tt_profile' >> ${profName}"
	execCmd ". ~/.tt_profile"
	execCmd "source ~/.tt_profile"

	echo_line "Setting up profiles...Done"
	echo_line "Please REOPEN your terminal!!!!"
}

function setupTasSky() {
	setupTas
	setupSky
	setupProfile
}
