#!/bin/bash

user_name=""
os=`uname`
pause=false
pass=0

function askUsername() {
	echo_color "----------------"
	echo_color " Init User Info "
	echo_color "----------------"

	echo_line "Make sure your ldap account is \"$(whoami)\". If yes press [Enter]"
	read -p "-> " user_name

	if [ "$user_name" = "" ]; then
	    user_name="$(whoami)"
	fi
}

function execCmd() {
	echo_exec "$1"
	if [ "$dryRun" = false ]; then
		eval $1
		checkFine
	fi
}

function exitProc() {
	echo
	echo_error "$1"
	exit 1
}

function echo_color() {
	echo -e "\033[34m$1\033[0m"
}

function echo_line() {
	echo ""
	echo_color "[$program_name] $1"
}

function echo_error() {
	echo -e "\033[31m[$program_name] $1\033[0m"
}

function echo_exec() {
	echo_color "[Exec] $1"
}

function gogo() {
	if [ "$pause" = true ]; then
		echo_line "Please press [Y] to continue, or [S] to skip."
		while read -r -n 1 -s answer; do
			if [[ $answer = [Yy] ]]; then
				pass=0
				return 0
			fi
			if [[ $answer = [Ss] ]]; then
				pass=1
				return 1
			fi
		done
	fi
	pass=0
}

function commandExists() {
	if ! type "$1" > /dev/null 2>&1; then
		return 1
	else
		return 0
	fi
}

# input
unset arrayTmp
# output
unset arrayKeys
unset arrayVals
unset selKey
unset selVal
unset retValue

# in: arrayTmp 
# out: retValue
function getValueByKey() {
	retValue=""
	for keyValue in "${arrayTmp[@]}";
	do
		if [ "${selKey}" = "${keyValue%%=*}" ]; then
			retValue="${keyValue##*=}"
			break
		fi
	done
}

# in: arrayTmp
# out: arrayKeys, arrayVals, selKey, selVal
function selectOption() {
	unset arrayKeys
	unset arrayVals
	unset selKey
	unset selVal
	PS3='# '
	for keyValue in "${arrayTmp[@]}";
	do
        arrayKeys+=("${keyValue%%=*}")
        arrayVals+=("${keyValue##*=}")
	done

	select selKey in "${arrayKeys[@]}";
	do
		# Check select option
		getValueByKey
		if [ ! "${retValue}" = "" ]; then
			selVal="${retValue}"
			echo_color "You select ${selKey}"
			echo_color "Value: ${selVal}"
			break
		fi
	done
}

function resetSelectOption() {
	# input
	unset arrayTmp
	# output
	unset arrayKeys
	unset arrayVals
	unset selKey
	unset selVal
}

function addKnownHosts() {
	if [ -z `ssh-keygen -F $1` ]; then
		ssh-keyscan -H $1 >> ~/.ssh/known_hosts
	fi
}

function checkFine() {
	rt=$?
	if [[ ${rt} -ne 0 ]]; then
		exit ${rt}
	fi
}

function sudoMkDir() {
	if [ ! -d $1 ]; then
		execCmd "sudo mkdir -p $1"
	fi
}

function mkDir() {
	if [ ! -d $1 ]; then
		execCmd "mkdir -p $1"
	fi
}

function sudoLnDir() {
	if [ -d $2 ]; then
		execCmd "sudo rm $2"
	fi
	execCmd "sudo ln -s $1 $2"
}

function lnDir() {
	if [ -d $2 ]; then
		execCmd "rm $2"
	fi
	execCmd "ln -s $1 $2"
}