#!/bin/bash

java_versions=(
	'jdk_1.8.0_74=https://raw.githubusercontent.com/caskroom/homebrew-cask/472930df191d66747a57d5c96c0d00511d56e21b/Casks/java.rb'
	)
java_locs=(
	'jdk_1.8.0_74=/Library/Java/JavaVirtualMachines/jdk1.8.0_74.jdk/Contents/Home'
	)

mysql_version=(
	'mysql_5.7=https://raw.githubusercontent.com/Homebrew/homebrew-core/dd4ce821a8f98be0875aa7c12691c655995275ff/Formula/mysql.rb'
	)

java_ver=""
java_loc=""
java_install_url=""

ant_ver="1.9.7"
brew_ant_url="https://raw.githubusercontent.com/Homebrew/homebrew-core/7bfaad6357dc3fa99aadbaff946ba5e903224752/Formula/ant.rb"
ant_loc="/usr/local/Cellar/ant/${ant_ver}/libexec"

git_ver="latest"

gradle_ver="4.6"
brew_gradle_url="https://raw.githubusercontent.com/Homebrew/homebrew-core/676b1d18fe9b25573fbe696bbcf100c5256aba3e/Formula/gradle.rb"

function setupApp() {
	echo_color "------------"
	echo_color " Brew Setup "
	echo_color "------------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	if ! commandExists "brew"; then
		echo_line "installing homebrew ..."
		ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"
		echo_line "install homebrew done"

		echo_line "installing brew-cask ..."
		execCmd "brew install caskroom/cask/brew-cask"
		echo_line "install brew-cask done"
	fi
	execCmd "brew update"
	execCmd "brew cleanup"
	# execCmd "brew cask cleanup"

	if ! commandExists "wget"; then
		echo_line "Installing wget ..."
		execCmd "brew install wget"
		echo_line "Installing wget done"
	fi
}

function selectJava() {
	if [ "${java_ver}" = "" ] || [ "${java_install_url}" = "" ] || [ "${java_loc}" = "" ]; then
		if [ "${isFullInstall}" = true ]; then
			java_ver="${java_versions[0]%%=*}"
			java_install_url="${java_versions[0]##*=}"
			java_loc="${java_locs[0]##*=}"
		else
			echo_line "Please select JAVA version."
			arrayTmp=(${java_versions[@]})
			selectOption
			java_ver="${selKey}"
			java_install_url="${selVal}"

			arrayTmp=(${java_locs[@]})
			getValueByKey
			java_loc="${retValue}"

			resetSelectOption
		fi
	fi
}

function installJava() {
	echo_color "------"
	echo_color " Java "
	echo_color "------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi
	selectJava

	echo_line "installing java..."
	execCmd "brew tap caskroom/versions"
	execCmd "brew cask install java8"

	sudoMkDir "${OPT_DIR}"
	
	echo_line "Link ${OPT_DIR}/jdk to $java_loc"
	sudoLnDir $java_loc $OPT_DIR/jdk
	echo_line "install java done"
}

function installGit() {
	if ! commandExists "git"; then
		echo_line "installing git... "
		execCmd "brew install git"
		echo_line "install git done"
	fi
}

function installGradle() {
	if commandExists "gradle"; then
		execCmd "brew uninstall gradle"
	fi

	echo_line "installing gradle... "
	execCmd "brew install $brew_gradle_url"
	echo_line "install gradle done"
}

function installAnt() {
	if ! commandExists "ant"; then
		echo_line "installing ant..."
		#ant_ver="1.9.4"
		execCmd "brew install $brew_ant_url"

		sudoMkDir "${OPT_DIR}"

		echo_line "Link ${OPT_DIR}/ant to $loc_ant"
		sudoLnDir $ant_loc $OPT_DIR/ant
		echo_line "install ant done"
	fi
}

function installMysql() {
	echo_color "-------------"
	echo_color " Setup MySql "
	echo_color "-------------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	if ! commandExists "mysql"; then
		execCmd "brew tap caskroom/versions"
		#execCmd "brew install ${mysql_version[0]##*=}"
		execCmd "brew install mysql"
		sudoMkDir "/etc/mysql/"
		execCmd "sudo cp ${CONF_DIR}/my.cnf /etc/mysql/"
		execCmd "mysql.server start"
	fi
}

#################################################################

function installDocker() {
	echo_color "--------"
	echo_color " Docker "
	echo_color "--------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	if ! commandExists "brew"; then
		setupBrew
	fi

	echo_line "Installing Docker... "
	if ! commandExists "docker"; then
		brew install docker
	fi
	if ! commandExists "boot2docker"; then
		brew install boot2docker
	fi
	if ! commandExists "VBoxManage"; then
		brew install Caskroom/cask/virtualbox
	fi
	echo_line "install Docker... done"
}

function setupDocker() {
	echo_color "--------------"
	echo_color " Setup Docker "
	echo_color "--------------"

	selectDockerfile
	moveJbossForDocker
	moveTasForDocker

	echo_line "Setting git config..."
	sed -i'' -e "/git config/d" $docker_sel_dir/first.sh
	echo "git config --global user.name \"$user_name\"" >> $docker_sel_dir/first.sh
	echo "git config --global user.email \"$user_name@truetel.com\"" >> $docker_sel_dir/first.sh

	askDockerInfo
	setupBoot2loader
	setupImages
}

function setupBoot2loader() {
	echo_color "-------------------"
	echo_color " Setup boot2docker "
	echo_color "-------------------"

	echo_line "Init boot2docker..."
	boot2docker init
	sleep 3

	echo_line "Execute... VBoxManage controlvm boot2docker-vm natpf1 \"dbport,tcp,,$docker_mysql_port,,3306\""
	VBoxManage controlvm boot2docker-vm natpf1 "dbport,tcp,,$docker_mysql_port,,3306"
	echo_line "Execute... VBoxManage controlvm boot2docker-vm natpf1 \"tasport,tcp,,$docker_tas_port,,6500\""
	VBoxManage controlvm boot2docker-vm natpf1 "tasport,tcp,,$docker_tas_port,,6500"
	echo_line "Execute... VBoxManage controlvm boot2docker-vm natpf1 \"debugport,tcp,,$docker_tas_debug,,6666\""
	VBoxManage controlvm boot2docker-vm natpf1 "debugport,tcp,,$docker_tas_debug,,6666"

	echo_line "Starting boot2docker..."
	boot2docker start

	sed -i'' -e "/export DOCKER_/d" ~/.tt_profile
	boot2docker shellinit >> ~/.tt_profile
	. ~/.tt_profile
}

function setupImages() {
	echo_color "-----------------"
	echo_color " Building Images "
	echo_color "-----------------"

	if [ ! "$(boot2docker status)" = "running" ]; then
		echo_error "boot2docker-vm is not running."
		return 1
	fi

	echo_line "Building..."
	echo_line "Build docker image cmd: $buildDocker"
	#askCmd $buildDocker
	execCmd "$buildDocker"
	sleep 2

	echo_line "Running..."
	echo_line "Run docker container cmd: $runDocker_mac"
	#askCmd $runDocker
	execCmd "$runDocker_mac"
	sleep 2

	echo_line "Starting..."
	echo_line "Exec docker cmd: $execDocker"
	#askCmd $execDocker
	execCmd "$execDocker"
}

function imageOnly() {
	if [ "$install_mode" = "Image only" ]; then
		askUsername
		setupProfile
	fi

	setupTas
	installDocker
	setupDocker

	setupTasrtenv
}
