#!/bin/bash

java_versions=(
	'java8=oracle-java8-installer'
	'java7=oracle-java7-installer'
	)

java_locs=(
	'java8=/usr/lib/jvm/java-8-oracle'
	'java7=/usr/lib/jvm/java-7-oracle'
	)

java_ver=""
java_install_url=""
java_loc=""

ant_ver=""
git_ver=""
gradle_ver="3.1"

function setupApp() {
	echo_color "---------------"
	echo_color " Setup apt-get "
	echo_color "---------------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	echo_line "Init Ubuntu apt-get..."
	execCmd "sudo apt-get -y install software-properties-common"
	execCmd "sudo add-apt-repository -y ppa:webupd8team/java"
	execCmd "sudo add-apt-repository -y ppa:cwchien/gradle"
	execCmd "sudo add-apt-repository -y ppa:git-core/ppa"
	execCmd "sudo apt-get -y update"
	echo_line "Init Ubuntu apt-get...Done"

	echo_line "Install sshd server..."
	execCmd "sudo apt-get -y install openssh-server"
	execCmd "sudo update-rc.d ssh defaults"
	echo_line "Install sshd server...Done"
}

function selectJava() {
	if [ "${java_ver}" = "" ] || [ "${java_install_url}" = "" ] || [ "${java_loc}" = "" ]; then
		if [ "${isFullInstall}" = true ]; then
			java_ver="${java_versions[0]%%=*}"
			java_install_url="${java_versions[0]##*=}"
			java_loc="${java_locs[0]##*=}"
		else
			echo_line "Please select JAVA version."
			arrayTmp=(${java_versions[@]})
			selectOption
			java_ver="${selKey}"
			java_install_url="${selVal}"

			arrayTmp=(${java_locs[@]})
			getValueByKey
			java_loc="${retValue}"

			resetSelectOption
		fi
	fi
}

function installJava() {
	echo_color "------"
	echo_color " Java "
	echo_color "------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	if commandExists "java"; then
		return 1
	fi

	selectJava

	echo_line "Install Java..."
	execCmd "sudo apt-get -y install python-software-properties"
	echo debconf shared/accepted-oracle-license-v1-1 select true | sudo debconf-set-selections
	echo debconf shared/accepted-oracle-license-v1-1 seen true | sudo debconf-set-selections
	execCmd "sudo apt-get -y install $java_install_url"
	
	sudoMkDir ${OPT_DIR}
	echo_line "Link ${OPT_DIR}/jdk to ${java_loc}"
	sudoLnDir $java_loc $OPT_DIR/jdk
	echo_line "Install Java...Done"
}

function installGit() {
	if ! commandExists "git"; then
		echo_line "Setup and config git... "

		execCmd "sudo apt-get -y install git"
		echo_line "Setup and config git... Done"
	fi
}

function installGradle() {
	if commandExists "gradle"; then
		echo_line "Remove gradle..."
		execCmd "sudo apt-get -y remove gradle-*"
	fi

	echo_line "Install gradle..."
	execCmd "sudo apt-get -y install gradle-${gradle_ver}"
	echo_line "Install gradle... Done"
}

function installAnt() {
	if ! commandExists "ant"; then
		echo_line "Install ant..."
		#ant_ver="1.9.3-2build1"
		execCmd "sudo apt-get -y install ant"

		sudoMkDir ${OPT_DIR}
		echo_line "Link $OPT_DIR/ant to /usr/share/ant"
		sudoLnDir /usr/share/ant $OPT_DIR/ant
		echo_line "Install ant... Done"
	fi
}

function installMysql() {
	echo_color "-------"
	echo_color " Mysql "
	echo_color "-------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	if commandExists "mysql"; then
		return 1
	fi

	echo_line "Install Mysql..."
	#echo "mysql-server-5.6 mysql-server/root_password password " | sudo debconf-set-selections
	#echo "mysql-server-5.6 mysql-server/root_password_again password " | sudo debconf-set-selections
	execCmd "sudo apt-get -y install mysql-server"
	sudoMkDir "/etc/mysql"
	execCmd "sudo cp ${CONF_DIR}/my.cnf /etc/mysql/"
	execCmd "sudo update-rc.d mysql defaults"
	execCmd "sudo /etc/init.d/mysql restart"
	
	echo_line "Install Mysql...Done"
}

function installDocker() {
	echo_color "----------------"
	echo_color " Install Docker "
	echo_color "----------------"
	gogo
	if [ $pass = 1 ]; then
		return 1
	fi

	if commandExists "docker"; then
		return 1
	fi

	echo "Install Docker..."
	execCmd "sudo wget -qO- https://get.docker.com/ | sh"
	execCmd "sudo usermod -aG docker $(whoami)"
	echo "Install Docker...Done"
}

function setupDocker() {
	echo_color "--------------"
	echo_color " Setup Docker "
	echo_color "--------------"

	selectDockerfile
	moveJbossForDocker
	moveTasForDocker

	echo_line "Setting config..."
	execCmd "sed -i -e '/git config/d' $docker_sel_dir/first.sh"
	echo "git config --global user.name \"${user_name}\"" >> $docker_sel_dir/first.sh
	echo "git config --global user.email \"${user_name}@truetel.com\"" >> $docker_sel_dir/first.sh

	askDockerInfo
	setupImages
}

function setupImages() {
	echo_color "-----------------"
	echo_color " Building Images "
	echo_color "-----------------"

	echo "cd $CUR_DIR" >> $CUR_DIR/setupAfter.sh
	echo "$buildDocker" >> $CUR_DIR/setupAfter.sh
	echo "sleep 2" >> $CUR_DIR/setupAfter.sh
	echo "$runDocker" >> $CUR_DIR/setupAfter.sh
	echo "sleep 2" >> $CUR_DIR/setupAfter.sh
	echo "echo 'You can execute \"$execDocker\" after.'" >> $CUR_DIR/setupAfter.sh
	echo "sed -i -e \"/setupAfter.sh/d\" ~/.tt_profile" >> $CUR_DIR/setupAfter.sh

	echo "if [ -f $CUR_DIR/setupAfter.sh ]; then . $CUR_DIR/setupAfter.sh ; fi" >> ~/.tt_profile
}

function imageOnly() {
	if [ "$install_mode" = "Image only" ]; then
		askUsername
		setupProfile
	fi

	setupTas
	installDocker
	setupDocker

	# Attention!! Because tasrtenv is follow the docker.
	setupTasrtenv

	echo_color "----------------------------------------"
	echo_color " Please REBOOT and open terminal again! "
	echo_color "----------------------------------------"
	echo_error "Docker need reboot to finish installation."
	echo_error "Press [Y] to REBOOT, or press [N] reboot after."
	while read -r -n 1 -s answer; do
	  if [[ $answer = [Yy] ]]; then
	  	execCmd "sudo reboot"
	    break
	  fi
	  if [[ $answer = [Nn] ]]; then
	    break
	  fi
	done
}
