#!/bin/bash

# Script Version V3.2
version_name="Dev-Setup-V2.0.0"

# Dir setting
CUR_DIR=`pwd`
TMP_DIR="${CUR_DIR}/tmp"
mkdir -p $TMP_DIR
CONF_DIR="${CUR_DIR}/config"
SCRIPT_DIR="${CUR_DIR}/scripts"

# Import common functions
. ${SCRIPT_DIR}/common_setup.sh
. ${SCRIPT_DIR}/general.sh
. ${SCRIPT_DIR}/docker.sh
install_mode=""
isFullInstall=false
options=("Full install" "Custom install" "Quit")

# for debug
directExec=false
dryRun=false

echo_color "DevSetup Version: ${version_name}"
case $os in
    "Darwin")
		echo_line "Import Mac's setup script"
		. ${SCRIPT_DIR}/mac.sh
        ;;
    "Linux")
		echo_line "Import Ubuntu's setup script"
		. ${SCRIPT_DIR}/ubuntu.sh
        ;;
    *) echo_error "Invalid OS. Your OS: ${os}"
		;;
esac


function selectInstall() {
	echo_color "----------------------------------"
	echo_color " Please select installation mode. "
	echo_color "----------------------------------"

	PS3='# '
	select install_mode in "${options[@]}"
	do
	    case $install_mode in
	        "${options[0]}")
				isFullInstall=true
	            oneKeyInstall
	            break
	            ;;
	        "${options[1]}")
	            customInstall
	            break
	            ;;
	        "${options[2]}")
				break
	            ;;
	        *) echo "Invalid option."
				;;
	    esac
	done
}

if [[ -n $1 ]]; then
	for i in $@
	do
		eval $i
	done
else
	selectInstall
fi